@@ -101,14 +101,14 @@ namespace {
 
         bool shouldFolderBeIndexed = Nepomuk2::FileIndexerConfig::self()->folderInFolderList( path );
 
-        // Only watch the index folders for file creation and change.
+        // Only watch the index folders for file change.
+        // We still need to monitor everything for file creation because directories count as
+        // files, and we want to recieve signals for a new directory, so that we can watch it.
         if( shouldFolderBeIndexed && shouldFileNameBeIndexed ) {
             modes |= KInotify::EventCloseWrite;
-            modes |= KInotify::EventCreate;
         }
         else {
             modes &= (~KInotify::EventCloseWrite);
-            modes &= (~KInotify::EventCreate);
         }
         return true;
     }
@@ -153,8 +153,8 @@ Nepomuk2::FileWatch::FileWatch()
     m_metadataMover->moveToThread(m_metadataMoverThread);
 
     m_fileModificationQueue = new ActiveFileQueue(this);
-    connect(m_fileModificationQueue, SIGNAL(urlTimeout(KUrl)),
-            this, SLOT(slotActiveFileQueueTimeout(KUrl)));
+    connect(m_fileModificationQueue, SIGNAL(urlTimeout(QString)),
+            this, SLOT(slotActiveFileQueueTimeout(QString)));
 
 #ifdef BUILD_KINOTIFY
     // monitor the file system for changes (restricted by the inotify limit)
@@ -334,7 +334,7 @@ void Nepomuk2::FileWatch::updateFolderViaFileIndexer( const QString& path )
 }
 
 
-void Nepomuk2::FileWatch::connectToKDirWatch()
+void Nepomuk2::FileWatch::connectToKDirNotify()
 {
     // monitor KIO for changes
     QDBusConnection::sessionBus().connect( QString(), QString(), "org.kde.KDirNotify", "FileMoved",
@@ -382,7 +382,7 @@ void Nepomuk2::FileWatch::slotInotifyWatchUserLimitReached( const QString& path
             m_dirWatch->deleteLater();
             m_dirWatch = 0;
         }
-        connectToKDirWatch();
+        connectToKDirNotify();
     }
 }
 #endif
@@ -520,10 +520,10 @@ void Nepomuk2::FileWatch::slotDeviceTeardownRequested(const Nepomuk2::RemovableM
 }
 
 
-void Nepomuk2::FileWatch::slotActiveFileQueueTimeout(const KUrl &url)
+void Nepomuk2::FileWatch::slotActiveFileQueueTimeout(const QString& url)
 {
     kDebug() << url;
-    updateFileViaFileIndexer(url.toLocalFile());
+    updateFileViaFileIndexer(url);
 }
 
 void Nepomuk2::FileWatch::updateStatusMessage(const QString &newStatus)
